Due to their fragile implementation, especially when custom commands are
defined in site settings, ``database dumps`` and ``database restore`` commands
are deprecated and will be removed in a future release.
